==> vonage_cloud_runtime-1.1.0-py3-none-any.whl: vonage_cloud_runtime/session/contracts/actionPayload.py <==
from dataclasses import dataclass, field, asdict
from typing import Dict, List, Generic, TypeVar
from abc import ABC, abstractmethod

from vonage_cloud_runtime.session.contracts.IActionPayload import IActionPayload
from vonage_cloud_runtime.session.contracts.IWrappedCallback import IWrappedCallback
T = TypeVar('T')
T = TypeVar("T")

@dataclass
class ActionPayload(IActionPayload,Generic[T]):
    payload: T
    action: str
    provider: str
    description: str = None
    successCallback: IWrappedCallback = None
    errorCallback: IWrappedCallback = None
    def __init__(self,provider: str,action: str,payload: T,description: str = None):
        self.provider = provider
        self.action = action
        self.payload = payload
        if description is not None:
            self.description = description
        
    
    def reprJSON(self):
        result = {}
        dict = asdict(self)
        keywordsMap = {"from_":"from","del_":"del","import_":"import","type_":"type"}
        for key in dict:
            val = getattr(self, key)

            if val is not None:
                if type(val) is list:
                    parsedList = []
                    for i in val:
                        if hasattr(i,'reprJSON'):
                            parsedList.append(i.reprJSON())
                        else:
                            parsedList.append(i)
                    val = parsedList

                if hasattr(val,'reprJSON'):
                    val = val.reprJSON()
                if key in keywordsMap:
                    key = keywordsMap[key]
                result.__setitem__(key.replace('_hyphen_', '-'), val)
        return result

==> vonage_cloud_runtime-1.4.0b1-py3-none-any.whl: vonage_cloud_runtime/session/contracts/actionPayload.py <==
from dataclasses import dataclass, field, asdict
from typing import Dict, List, Generic, TypeVar
from abc import ABC, abstractmethod

from vonage_cloud_runtime.session.contracts.IActionPayload import IActionPayload
from vonage_cloud_runtime.session.contracts.IWrappedCallback import IWrappedCallback
T = TypeVar('T')
T = TypeVar("T")

@dataclass
class ActionPayload(IActionPayload,Generic[T]):
    payload: T
    action: str
    provider: str
    description: str = None
    successCallback: IWrappedCallback = None
    errorCallback: IWrappedCallback = None
    def __init__(self,provider: str,action: str,payload: T,description: str = None):
        self.provider = provider
        self.action = action
        self.payload = payload
        if description is not None:
            self.description = description
        
    
    def reprJSON(self):
        result = {}
        dict = asdict(self)
        keywordsMap = {"from_":"from","del_":"del","import_":"import","type_":"type", "return_":"return"}
        for key in dict:
            val = getattr(self, key)

            if val is not None:
                if type(val) is list:
                    parsedList = []
                    for i in val:
                        if hasattr(i,'reprJSON'):
                            parsedList.append(i.reprJSON())
                        else:
                            parsedList.append(i)
                    val = parsedList

                if hasattr(val,'reprJSON'):
                    val = val.reprJSON()
                if key in keywordsMap:
                    key = keywordsMap[key]
                result.__setitem__(key.replace('_hyphen_', '-'), val)
        return result
